@@ -9,12 +9,6 @@ debuglevel = 0
 #logfile = ''
 logfile = '/var/log/serpento.log'
 
-# caching = 1 or 0
-# if 1, cPickle internal index list the first time
-# serpento is started, and use cPickled cache the next times
-# this improves startup time a lot
-caching = 1
-
-# directory to put cPickled cache files into
+# directory to put cache files into
 cachedir = '/var/cache/serpento'
 
